import { ForumTest } from './forum.test-util.js';

describe('Forum', () => {
  const forumTest = new ForumTest();

  before(async () => {
    await forumTest.setup();
  });

  context('Redistribute power', async () => {
    it('Post1', async () => {
      const { forum, experts, posts } = forumTest;
      await forumTest.addPost(experts[0], 20);
      forum.getPost(posts[0]).value.should.equal(20);
    });

    it('Post2', async () => {
      const { forum, experts, posts } = forumTest;
      await forumTest.addPost(experts[0], 10);
      forum.getPost(posts[0]).value.should.equal(20);
      forum.getPost(posts[1]).value.should.equal(10);
    });

    it('Post3 cites Post2 and negatively cites Post1', async () => {
      const { forum, experts, posts } = forumTest;
      await forumTest.addPost(experts[0], 10, [
        { postId: posts[0], weight: -0.5 },
        { postId: posts[1], weight: 0.5 },
      ]);
      forum.getPost(posts[0]).value.should.equal(15);
      forum.getPost(posts[1]).value.should.equal(15);
      forum.getPost(posts[2]).value.should.equal(10);
    });

    it('Post4 copies Post3 to increase its power', async () => {
      const { forum, experts, posts } = forumTest;
      await forumTest.addPost(experts[0], 10, [
        { postId: posts[0], weight: -0.5 },
        { postId: posts[1], weight: 0.5 },
      ]);
      forum.getPost(posts[0]).value.should.equal(10);
      forum.getPost(posts[1]).value.should.equal(20);
      forum.getPost(posts[2]).value.should.equal(10);
      forum.getPost(posts[3]).value.should.equal(10);
    });
    it('Post5 cites Post3 and Post4 to increase their power', async () => {
      const { forum, experts, posts } = forumTest;
      await forumTest.addPost(experts[0], 20, [
        { postId: posts[2], weight: 0.5 },
        { postId: posts[3], weight: 0.5 },
      ]);
      forum.getPost(posts[0]).value.should.equal(0);
      forum.getPost(posts[1]).value.should.equal(40);
      forum.getPost(posts[2]).value.should.equal(40);
      forum.getPost(posts[3]).value.should.equal(0);
    });
  });
});

// await addPost(experts[0], 10);
// await addPost(experts[0], 10, [{ postId: posts[3], weight: -1 }]);
// await addPost(experts[0], 10, [{ postId: posts[4], weight: -1 }]);

// await addPost(expert3, 'Post 4', 100, [{ postId: postId2, weight: -1 }]);
// await addPost(expert1, 'Post 5', 100, [{ postId: postId3, weight: -1 }]);
